<!doctype html>
<html lang="ru">
<head>
  <meta charset="UTF-8">
  <meta
    name="viewport"
    content="width=device-width, user-scalable=no, initial-scale=1.0, maximum-scale=1.0, minimum-scale=1.0"
  >
  <meta http-equiv="X-UA-Compatible" content="ie=edge">
  <title>Debug Payment</title>
</head>
<body>
<form action="{% url 'django_pay2:debug_accept' pk=payment.pk %}" method="post">
  {% csrf_token %}
  <button type="submit">Подтвердить</button>
</form>
<form action="{% url 'django_pay2:debug_reject' pk=payment.pk %}" method="post">
  {% csrf_token %}
  <button type="submit">Отклонить</button>
</form>
</body>
</html>
